![Documentation](https://github.com/krishols/designer/actions/workflows/docs.yml/badge.svg)
# Designer
An interactive graphics library designed with student data to learn Python.

# Installation
Install from the command line: 

 ```
 pip install designer
 ```
  
Or install from [this repository](https://github.com/krishols/designer).

# Documentation
Find the documentation for Designer [here](https://designer-edu.github.io/designer/).

# External Resources

* Designer takes heavily from Spyral, and shares a maintainer in @acbart
* Designer's emoji support is via [Twemoji](https://github.com/twitter/twemoji)
  * Copyright 2020 Twitter, Inc and other contributors
  * Code licensed under the MIT License: http://opensource.org/licenses/MIT
  * Graphics licensed under CC-BY 4.0: https://creativecommons.org/licenses/by/4.0/
* Designer is obviously built on Pygame

# Future

* Make `group` use the Spyral `View` mechanims. Provide a "frozen group" and a "dynamic group".
* Support for `turtle` style graphics, using animations
* More basic shapes like `triangle`, `star`, ...?
* Handle *potential* collision checks "if the object were placed here", circular, etc.
* Update documentation to explain the `destroy` function
* Improve the error handling in as many situations as possible
